diff --git a/Cosmos.sln b/Cosmos.sln
index 748e7ee6e..2e10c44eb 100644
--- a/Cosmos.sln
+++ b/Cosmos.sln
@@ -169,6 +169,12 @@ Project("{471EC4BB-E47E-4229-A789-D1F5F83B52D4}") = "GuessKernelBoot", "Demos\Gu
EndProject
Project("{9A19103F-16F7-4668-BE54-9A1E7A4F7556}") = "Cosmos.Core.Memory.Test", "Tests\Cosmos.Core.Memory.Test\Cosmos.Core.Memory.Test.csproj", "{408E5ACC-EA9A-41E8-AA95-514C5F47BD34}"
EndProject
+Project("{2150E333-8FDC-42A3-9474-1A3956D46DE8}") = "Cosmos Graphic Subsystem", "Cosmos Graphic Subsystem", "{A9D558E8-B0C7-4FF6-99D8-CB2BC6FEB7C7}"
+EndProject
+Project("{9A19103F-16F7-4668-BE54-9A1E7A4F7556}") = "Cosmos Graphic Subsystem", "Demos\Cosmos Graphic Subsystem\Cosmos Graphic Subsystem.csproj", "{49F2C01D-D2C5-4564-810B-1AE92236C5C1}"
+EndProject
+Project("{471EC4BB-E47E-4229-A789-D1F5F83B52D4}") = "Cosmos Graphic SubsystemBoot", "Demos\Cosmos Graphic Subsystem\Cosmos Graphic SubsystemBoot.Cosmos", "{79D68062-46C5-466D-9289-C033F7348485}"
+EndProject
Global
GlobalSection(SolutionConfigurationPlatforms) = preSolution
Debug|Any CPU = Debug|Any CPU
@@ -649,6 +655,21 @@ Global
{408E5ACC-EA9A-41E8-AA95-514C5F47BD34}.Release|Any CPU.Build.0 = Release|Any CPU
{408E5ACC-EA9A-41E8-AA95-514C5F47BD34}.Release|x86.ActiveCfg = Release|Any CPU
{408E5ACC-EA9A-41E8-AA95-514C5F47BD34}.Release|x86.Build.0 = Release|Any CPU
+ {49F2C01D-D2C5-4564-810B-1AE92236C5C1}.Debug|Any CPU.ActiveCfg = Debug|Any CPU
+ {49F2C01D-D2C5-4564-810B-1AE92236C5C1}.Debug|Any CPU.Build.0 = Debug|Any CPU
+ {49F2C01D-D2C5-4564-810B-1AE92236C5C1}.Debug|x86.ActiveCfg = Debug|Any CPU
+ {49F2C01D-D2C5-4564-810B-1AE92236C5C1}.Debug|x86.Build.0 = Debug|Any CPU
+ {49F2C01D-D2C5-4564-810B-1AE92236C5C1}.Release|Any CPU.ActiveCfg = Release|Any CPU
+ {49F2C01D-D2C5-4564-810B-1AE92236C5C1}.Release|Any CPU.Build.0 = Release|Any CPU
+ {49F2C01D-D2C5-4564-810B-1AE92236C5C1}.Release|x86.ActiveCfg = Release|Any CPU
+ {49F2C01D-D2C5-4564-810B-1AE92236C5C1}.Release|x86.Build.0 = Release|Any CPU
+ {79D68062-46C5-466D-9289-C033F7348485}.Debug|Any CPU.ActiveCfg = Debug|Any CPU
+ {79D68062-46C5-466D-9289-C033F7348485}.Debug|x86.ActiveCfg = Debug|Any CPU
+ {79D68062-46C5-466D-9289-C033F7348485}.Debug|x86.Build.0 = Debug|Any CPU
+ {79D68062-46C5-466D-9289-C033F7348485}.Release|Any CPU.ActiveCfg = Release|Any CPU
+ {79D68062-46C5-466D-9289-C033F7348485}.Release|Any CPU.Build.0 = Release|Any CPU
+ {79D68062-46C5-466D-9289-C033F7348485}.Release|x86.ActiveCfg = Release|Any CPU
+ {79D68062-46C5-466D-9289-C033F7348485}.Release|x86.Build.0 = Release|Any CPU
EndGlobalSection
GlobalSection(SolutionProperties) = preSolution
HideSolutionNode = FALSE
@@ -723,5 +744,8 @@ Global
{E35E0DBF-555F-4D38-8F28-ACDFA9DC97BD} = {5FF9BF2A-5162-4F12-82B6-1693AD776636}
{77DD08F5-0751-4EFC-B222-78F9F06E1F7C} = {5FF9BF2A-5162-4F12-82B6-1693AD776636}
{408E5ACC-EA9A-41E8-AA95-514C5F47BD34} = {52D81759-C7CC-427F-8C96-89CA10C914B5}
+ {A9D558E8-B0C7-4FF6-99D8-CB2BC6FEB7C7} = {B56A6119-1B8F-44E4-9446-291E52F47D4C}
+ {49F2C01D-D2C5-4564-810B-1AE92236C5C1} = {A9D558E8-B0C7-4FF6-99D8-CB2BC6FEB7C7}
+ {79D68062-46C5-466D-9289-C033F7348485} = {A9D558E8-B0C7-4FF6-99D8-CB2BC6FEB7C7}
EndGlobalSection
EndGlobal
diff --git a/Demos/Cosmos Graphic Subsystem/Cosmos Graphic Subsystem.csproj b/Demos/Cosmos Graphic Subsystem/Cosmos Graphic Subsystem.csproj
new file mode 100644
index 000000000..ea3ee692d
--- /dev/null
+++ b/Demos/Cosmos Graphic Subsystem/Cosmos Graphic Subsystem.csproj
@@ -0,0 +1,17 @@
+
+
+
+ netstandard1.5
+ {49f2c01d-d2c5-4564-810b-1ae92236c5c1}
+
+
+
+
+
+
+
+
+
+
+
+
diff --git a/Demos/Cosmos Graphic Subsystem/Cosmos Graphic SubsystemBoot.Cosmos b/Demos/Cosmos Graphic Subsystem/Cosmos Graphic SubsystemBoot.Cosmos
new file mode 100644
index 000000000..9d41e4c4c
--- /dev/null
+++ b/Demos/Cosmos Graphic Subsystem/Cosmos Graphic SubsystemBoot.Cosmos
@@ -0,0 +1,60 @@
+
+
+
+ net462
+
+
+
+ elf
+ True
+ Source
+ User
+ False
+ False
+ ISO
+ Pipe: Cosmos\Serial
+ True
+ MethodFooters
+ False
+ Serial: COM1
+ VMware
+ VMware
+ Use VMware Player or Workstation to deploy and debug.
+
+
+
+
+
+
+
+
+
+ Cosmos.Core.Plugs.Asm
+ {3c186d37-21c3-417c-95f1-19be538af88a}
+ True
+
+
+ Cosmos.Core.Plugs
+ {1132e689-18b0-4d87-94e8-934d4802c540}
+ True
+
+
+ Cosmos.Debug.Kernel.Plugs.Asm
+ {7e450662-b34c-49b0-a826-f45ad3a18891}
+ True
+
+
+ Cosmos.System.Plugs
+ {9431ff1f-ad75-4a1e-b38a-46e0f109411d}
+ True
+
+
+ Cosmos Graphic Subsystem
+ {49f2c01d-d2c5-4564-810b-1ae92236c5c1}
+ True
+
+
+
+
+
+
\ No newline at end of file
diff --git a/Demos/Cosmos Graphic Subsytem/Kernel.cs b/Demos/Cosmos Graphic Subsystem/Kernel.cs
similarity index 100%
rename from Demos/Cosmos Graphic Subsytem/Kernel.cs
rename to Demos/Cosmos Graphic Subsystem/Kernel.cs
diff --git a/Demos/Cosmos Graphic Subsytem/AssemblyInfo.cs b/Demos/Cosmos Graphic Subsytem/AssemblyInfo.cs
deleted file mode 100644
index 6848b03ad..000000000
--- a/Demos/Cosmos Graphic Subsytem/AssemblyInfo.cs
+++ /dev/null
@@ -1,36 +0,0 @@
-using System;
-using System.Reflection;
-using System.Resources;
-using System.Runtime.CompilerServices;
-using System.Runtime.InteropServices;
-
-// General Information about an assembly is controlled through the following
-// set of attributes. Change these attribute values to modify the information
-// associated with an assembly.
-[assembly: AssemblyTitle("Package Name")]
-[assembly: AssemblyDescription("")]
-[assembly: AssemblyConfiguration("")]
-[assembly: AssemblyCompany("Company")]
-[assembly: AssemblyProduct("Package Name")]
-[assembly: AssemblyCopyright("")]
-[assembly: AssemblyTrademark("")]
-[assembly: AssemblyCulture("")]
-[assembly: ComVisible(false)]
-[assembly: CLSCompliant(false)]
-[assembly: NeutralResourcesLanguage("en-US")]
-
-// Version information for an assembly consists of the following four values:
-//
-// Major Version
-// Minor Version
-// Build Number
-// Revision
-//
-// You can specify all the values or you can default the Revision and Build Numbers
-// by using the '*' as shown below:
-
-[assembly: AssemblyVersion("1.0.0.0")]
-[assembly: AssemblyFileVersion("1.0.0.0")]
-
-
-
diff --git a/Demos/Cosmos Graphic Subsytem/Cosmos Graphic Subsytem.csproj b/Demos/Cosmos Graphic Subsytem/Cosmos Graphic Subsytem.csproj
deleted file mode 100644
index c0f8c3f50..000000000
--- a/Demos/Cosmos Graphic Subsytem/Cosmos Graphic Subsytem.csproj
+++ /dev/null
@@ -1,62 +0,0 @@
-
-
-
- Debug
- x86
- 9.0.30729
- 2.0
- {49F2C01D-D2C5-4564-810B-1AE92236C5C1}
- Library
- Properties
- Cosmos_Graphic_Subsytem
- Cosmos Graphic Subsytem
- 512
- v4.5.2
-
-
-
- true
- bin\Debug\
- DEBUG;TRACE
- full
- x86
- prompt
- MinimumRecommendedRules.ruleset
-
-
- bin\Release\
- TRACE
- true
- pdbonly
- x86
- prompt
- MinimumRecommendedRules.ruleset
-
-
-
-
-
-
-
-
-
-
-
-
- {61607f1e-58f9-41cf-972f-128384f3e115}
- Cosmos.Debug.Kernel
-
-
- {3def0461-08ab-471a-8f03-a9c556652a0f}
- Cosmos.System
-
-
-
-
-
\ No newline at end of file
diff --git a/Demos/Cosmos Graphic Subsytem/Cosmos Graphic SubsytemBoot.Cosmos b/Demos/Cosmos Graphic Subsytem/Cosmos Graphic SubsytemBoot.Cosmos
deleted file mode 100644
index 54c3ee86f..000000000
--- a/Demos/Cosmos Graphic Subsytem/Cosmos Graphic SubsytemBoot.Cosmos
+++ /dev/null
@@ -1,70 +0,0 @@
-
-
-
- Debug
- 2.0
- {1bc71853-22f3-415d-a068-8e1fa8e8f05b}
- false
- Cosmos Graphic SubsytemBoot
- elf
- v4.5.2
-
-
-
- Bochs
- true
- Source
- User
- False
- false
- Player
- bin\Debug\
- Cosmos Graphic SubsytemBoot
- Use Bochs emulator to deploy and debug.
- ISO
- Bochs
- Pipe: Cosmos\Serial
- 192.168.0.3
- Cosmos Graphic SubsytemBoot
- Use VMware Player or Workstation to deploy and debug.
- ISO
- VMware
- true
- Source
- Pipe: Cosmos\Serial
- 192.168.0.3
- Player
- bin\Debug\
- False
- false
- Cosmos Graphic SubsytemBoot
- Use Bochs emulator to deploy and debug.
- ISO
- Bochs
- true
- Source
- Pipe: Cosmos\Serial
- 192.168.0.3
- Player
- bin\Debug\
- False
- false
-
-
-
- Cosmos Graphic Subsytem
- {49f2c01d-d2c5-4564-810b-1ae92236c5c1}
-
-
-
-
-
-
-
-
-
-
\ No newline at end of file
diff --git a/Demos/Guess/GuessKernel.csproj b/Demos/Guess/GuessKernel.csproj
index 0f1ee094f..aa5489b4b 100644
--- a/Demos/Guess/GuessKernel.csproj
+++ b/Demos/Guess/GuessKernel.csproj
@@ -2,6 +2,7 @@
netstandard1.5
+ {e35e0dbf-555f-4d38-8f28-acdfa9dc97bd}
diff --git a/Demos/Guess/GuessKernelBoot.Cosmos b/Demos/Guess/GuessKernelBoot.Cosmos
index 2d421f6e8..e7c889f72 100644
--- a/Demos/Guess/GuessKernelBoot.Cosmos
+++ b/Demos/Guess/GuessKernelBoot.Cosmos
@@ -4,7 +4,8 @@
net462
-
+
+ elf
True
Source
User
@@ -27,18 +28,32 @@
+
+ Cosmos.Core.Plugs.Asm
+ {3c186d37-21c3-417c-95f1-19be538af88a}
+ True
+
+
+ Cosmos.Core.Plugs
+ {1132e689-18b0-4d87-94e8-934d4802c540}
+ True
+
+
+ Cosmos.Debug.Kernel.Plugs.Asm
+ {7e450662-b34c-49b0-a826-f45ad3a18891}
+ True
+
+
+ Cosmos.System.Plugs
+ {9431ff1f-ad75-4a1e-b38a-46e0f109411d}
+ True
+
GuessKernel
{e35e0dbf-555f-4d38-8f28-acdfa9dc97bd}
-
-
-
-
-
-
-
+
diff --git a/Setup/Cosmos.iss b/Setup/Cosmos.iss
index 3bfc24eab..2650ee6be 100644
--- a/Setup/Cosmos.iss
+++ b/Setup/Cosmos.iss
@@ -92,7 +92,8 @@ Source: ".\Build\VSIP\Cosmos.Common.*"; DestDir: "{app}\Kernel"; Flags: ignoreve
Source: ".\Build\VSIP\KernelPackages\*.nupkg"; DestDir: "{app}\Kernel\packages"; Flags: ignoreversion uninsremovereadonly
; Icon
Source: ".\Artwork\Cosmos.ico"; DestDir: "{app}"; Flags: ignoreversion uninsremovereadonly
-; XSharp Source
+; XSharp
+Source: ".\Artwork\XSharp\XSharp.ico"; DestDir: "{app}\XSharp\"; Flags: ignoreversion uninsremovereadonly
Source: ".\source\Cosmos.Debug.DebugStub\*.xs"; DestDir: "{app}\XSharp\DebugStub\"; Flags: ignoreversion uninsremovereadonly
; VMware
Source: ".\Build\VMware\*"; DestDir: "{app}\Build\VMware"; Flags: ignoreversion uninsremovereadonly overwritereadonly recursesubdirs
@@ -109,14 +110,19 @@ Source: ".\Build\mboot.c32"; DestDir: "{app}\Build\PXE\"
Source: ".\Build\syslinux.cfg"; DestDir: "{app}\Build\PXE\pxelinux.cfg"; DestName: "default"
; VSIP
Source: ".\Build\Tools\VSIXBootstrapper.exe"; DestDir: "{app}\Build\Tools"; Flags: ignoreversion uninsremovereadonly
-Source: ".\Build\VSIP\Cosmos.VS.ProjectSystem.vsix"; DestDir: "{app}"; Flags: ignoreversion uninsremovereadonly
-Source: ".\Build\VSIP\Cosmos.VS.Windows.vsix"; DestDir: "{app}"; Flags: ignoreversion uninsremovereadonly
-Source: ".\Build\VSIP\Cosmos.VS.DebugEngine.vsix"; DestDir: "{app}"; Flags: ignoreversion uninsremovereadonly
-Source: ".\Build\VSIP\XSharp.VS.vsix"; DestDir: "{app}"; Flags: ignoreversion uninsremovereadonly
+Source: ".\Build\VSIP\Cosmos.VS.ProjectSystem.vsix"; DestDir: "{app}\VSIX\"; Flags: ignoreversion uninsremovereadonly
+;Source: ".\Build\VSIP\Cosmos.VS.Windows.vsix"; DestDir: "{app}"; Flags: ignoreversion uninsremovereadonly
+;Source: ".\Build\VSIP\Cosmos.VS.DebugEngine.vsix"; DestDir: "{app}"; Flags: ignoreversion uninsremovereadonly
+Source: ".\Build\VSIP\XSharp.VS.vsix"; DestDir: "{app}\VSIX\"; Flags: ignoreversion uninsremovereadonly
; MSBuild targets
Source: ".\Build\VSIP\Cosmos.targets"; DestDir: "{code:GetMSBuildDirectory}\Cosmos"; Flags: ignoreversion uninsremovereadonly
[Registry]
+; Regiter .xs Extension
+Root: HKCR; Subkey: ".xs"; ValueType: string; ValueName: ""; ValueData: "XSharp"; Flags: uninsdeletevalue
+Root: HKCR; Subkey: "XSharp"; ValueType: string; ValueName: ""; ValueData: "X# source file"; Flags: uninsdeletekey
+Root: HKCR; Subkey: "XSharp\DefaultIcon"; ValueType: string; ValueName: ""; ValueData: "{app}\XSharp\XSharp.ico,0"
+Root: HKCR; Subkey: "XSharp\shell\open\command"; ValueType: string; ValueName: ""; ValueData: """{app}\Build\XSharp\XSC.exe"" ""%1"""
; User Kit Folder
Root: HKLM; SubKey: Software\Cosmos; ValueType: string; ValueName: "UserKit"; ValueData: {app}; Flags: uninsdeletekey
; Dev Kit Folder - Set by builder only, but we delete it here. See comments in builder.
@@ -131,7 +137,9 @@ UseRelativePaths=True
Filename: "{app}\Build\Tools\nuget.exe"; Parameters: "init ""{app}\Kernel\packages"" ""{app}\Kernel\packages"""; WorkingDir: "{app}"; Description: "Install Kernel Packages"; StatusMsg: "Installing Kernel Packages"
Filename: "{app}\Build\Tools\nuget.exe"; Parameters: "sources Add -Name ""Cosmos Local Package Feed"" -Source ""{app}\Kernel\packages"""; WorkingDir: "{app}"; Description: "Install Kernel Packages"; StatusMsg: "Installing Kernel Packages"
Filename: "{app}\Build\Tools\VSIXBootstrapper.exe"; Parameters: "/q /a /u:Cosmos.VS.ProjectSystem"; Description: "Remove Cosmos Project System"; StatusMsg: "Removing Visual Studio Extension: Cosmos Project System"
-Filename: "{app}\Build\Tools\VSIXBootstrapper.exe"; Parameters: "/q /a Cosmos.VS.ProjectSystem.vsix"; WorkingDir: "{app}"; Description: "Install Cosmos Project System"; StatusMsg: "Installing Visual Studio Extension: Cosmos Project System"
+;Filename: "{app}\Build\Tools\VSIXBootstrapper.exe"; Parameters: "/q /a /u:XSharp.VS"; Description: "Remove Cosmos Project System"; StatusMsg: "Removing Visual Studio Extension: Cosmos X# Language"
+Filename: "{app}\Build\Tools\VSIXBootstrapper.exe"; Parameters: "/q /a Cosmos.VS.ProjectSystem.vsix"; WorkingDir: "{app}\Extensions\"; Description: "Install Cosmos Project System"; StatusMsg: "Installing Visual Studio Extension: Cosmos Project System"
+;Filename: "{app}\Build\Tools\VSIXBootstrapper.exe"; Parameters: "/q /a XSharp.VS.vsix"; WorkingDir: "{app}\Extensions\"; Description: "Install Cosmos Project System"; StatusMsg: "Installing Visual Studio Extension: Cosmos X# Language"
[UninstallRun]
Filename: "{code:GetVsixInstallCommand}"; Parameters: "{code:GetVsixUninstallParams|Cosmos.VS.ProjectSystem}"
diff --git a/source/Cosmos.VS.DebugEngine/Cosmos.VS.DebugEngine.csproj b/source/Cosmos.VS.DebugEngine/Cosmos.VS.DebugEngine.csproj
index 77e4c2e79..702974d63 100644
--- a/source/Cosmos.VS.DebugEngine/Cosmos.VS.DebugEngine.csproj
+++ b/source/Cosmos.VS.DebugEngine/Cosmos.VS.DebugEngine.csproj
@@ -38,6 +38,7 @@
DEBUG;TRACE
prompt
4
+ False
pdbonly
diff --git a/source/Cosmos.VS.ProjectSystem/Cosmos.VS.ProjectSystem.csproj b/source/Cosmos.VS.ProjectSystem/Cosmos.VS.ProjectSystem.csproj
index 44cf0fa19..3d91a0638 100644
--- a/source/Cosmos.VS.ProjectSystem/Cosmos.VS.ProjectSystem.csproj
+++ b/source/Cosmos.VS.ProjectSystem/Cosmos.VS.ProjectSystem.csproj
@@ -39,6 +39,7 @@
DEBUG;TRACE
prompt
4
+ False
pdbonly
diff --git a/source/Cosmos.VS.ProjectSystem/ProjectTemplates/CosmosKernel (CSharp)/CSharpProject.csproj b/source/Cosmos.VS.ProjectSystem/ProjectTemplates/CosmosKernel (CSharp)/CSharpProject.csproj
index 0b079632b..7dcf06ab6 100644
--- a/source/Cosmos.VS.ProjectSystem/ProjectTemplates/CosmosKernel (CSharp)/CSharpProject.csproj
+++ b/source/Cosmos.VS.ProjectSystem/ProjectTemplates/CosmosKernel (CSharp)/CSharpProject.csproj
@@ -2,13 +2,11 @@
netstandard1.5
- $safeprojectname$
- $safeprojectname$
$KernelProjectGuid$
-
+
diff --git a/source/Cosmos.VS.ProjectSystem/ProjectTemplates/CosmosProject (CSharp)/CSharpProject.csproj b/source/Cosmos.VS.ProjectSystem/ProjectTemplates/CosmosProject (CSharp)/CSharpProject.csproj
index 8f7acd167..555e64893 100644
--- a/source/Cosmos.VS.ProjectSystem/ProjectTemplates/CosmosProject (CSharp)/CSharpProject.csproj
+++ b/source/Cosmos.VS.ProjectSystem/ProjectTemplates/CosmosProject (CSharp)/CSharpProject.csproj
@@ -2,8 +2,6 @@
netstandard1.5
- $safeprojectname$
- $safeprojectname$
$KernelProjectGuid$
diff --git a/source/Cosmos.VS.Windows/Cosmos.VS.Windows.csproj b/source/Cosmos.VS.Windows/Cosmos.VS.Windows.csproj
index 71dc215df..c4f8ac6c4 100644
--- a/source/Cosmos.VS.Windows/Cosmos.VS.Windows.csproj
+++ b/source/Cosmos.VS.Windows/Cosmos.VS.Windows.csproj
@@ -38,6 +38,7 @@
DEBUG;TRACE
prompt
4
+ False
pdbonly
diff --git a/source/XSharp.VS/Scanner.cs b/source/XSharp.VS/Scanner.cs
index 11b6da6b7..e471dfe18 100644
--- a/source/XSharp.VS/Scanner.cs
+++ b/source/XSharp.VS/Scanner.cs
@@ -25,7 +25,7 @@ namespace XSharp.VS
static Scanner()
{
- int xEnumMax = Enum.GetValues(typeof(TokenType)).GetUpperBound(0);
+ int xEnumMax = Enum.GetValues(typeof(XSC.TokenType)).GetUpperBound(0);
mTokenMap = new TokenData[xEnumMax + 1];
// Set Default values
diff --git a/source/XSharp.VS/XSharp.VS.csproj b/source/XSharp.VS/XSharp.VS.csproj
index 193c20065..22df14128 100644
--- a/source/XSharp.VS/XSharp.VS.csproj
+++ b/source/XSharp.VS/XSharp.VS.csproj
@@ -3,6 +3,14 @@
15.0
+ $(MSBuildExtensionsPath32)\Microsoft\VisualStudio\v$(VisualStudioVersion)
+ true
+
+
+ true
+
+
+ ..\..\Cosmos.snk
@@ -22,10 +30,6 @@
true
true
false
- true
- ..\..\Cosmos.snk
- true
- True
true
@@ -49,10 +53,10 @@
-
+
-
+
@@ -66,7 +70,9 @@
Cosmos.snk
-
+
+ Designer
+
Designer
@@ -149,17 +155,15 @@
..\..\packages\Microsoft.VisualStudio.TextManager.Interop.8.0.8.0.50727\lib\Microsoft.VisualStudio.TextManager.Interop.8.0.dll
True
-
- ..\..\packages\Microsoft.VisualStudio.Threading.15.0.240\lib\net45\Microsoft.VisualStudio.Threading.dll
- True
+
+ ..\..\packages\Microsoft.VisualStudio.Threading.15.3.20\lib\net45\Microsoft.VisualStudio.Threading.dll
..\..\packages\Microsoft.VisualStudio.Utilities.15.0.26201\lib\net45\Microsoft.VisualStudio.Utilities.dll
True
-
- ..\..\packages\Microsoft.VisualStudio.Validation.15.0.82\lib\net45\Microsoft.VisualStudio.Validation.dll
- True
+
+ ..\..\packages\Microsoft.VisualStudio.Validation.15.3.15\lib\net45\Microsoft.VisualStudio.Validation.dll
@@ -171,16 +175,20 @@
+
+ ..\..\packages\System.Reflection.4.1.0\lib\net462\System.Reflection.dll
+ True
+
+
+ ..\..\packages\System.Reflection.TypeExtensions.4.1.0\lib\net462\System.Reflection.TypeExtensions.dll
+ True
+
..\..\packages\System.Runtime.4.1.0\lib\net462\System.Runtime.dll
True
-
- ..\..\packages\System.Runtime.InteropServices.4.1.0\lib\net462\System.Runtime.InteropServices.dll
- True
-
-
- ..\..\packages\System.Threading.Thread.4.3.0\lib\net46\System.Threading.Thread.dll
+
+ ..\..\packages\System.Runtime.Extensions.4.1.0\lib\net462\System.Runtime.Extensions.dll
True
@@ -210,6 +218,10 @@
+
+
diff --git a/source/Cosmos.System/Graphics/Canvas.cs b/source/Cosmos.System/Graphics/Canvas.cs
index bcb4ffa07..7c55b02ad 100644
--- a/source/Cosmos.System/Graphics/Canvas.cs
+++ b/source/Cosmos.System/Graphics/Canvas.cs
@@ -11,14 +11,14 @@ namespace Cosmos.System.Graphics
public abstract class Canvas
{
protected Mode mode;
- protected List aviableModes;
+ protected List availableModes;
static protected Mode defaultGraphicMode;
protected Canvas(Mode mode)
{
//Global.mDebugger.SendInternal($"Creating a new Canvas with Mode ${mode}");
- aviableModes = getAviableModes();
+ availableModes = getAvailableModes();
defaultGraphicMode = getDefaultGraphicMode();
this.mode = mode;
}
@@ -27,20 +27,20 @@ namespace Cosmos.System.Graphics
{
Global.mDebugger.SendInternal($"Creating a new Canvas with default graphic Mode");
- aviableModes = getAviableModes();
+ availableModes = getAvailableModes();
defaultGraphicMode = getDefaultGraphicMode();
this.mode = defaultGraphicMode;
}
- abstract public List getAviableModes();
+ abstract public List getAvailableModes();
abstract protected Mode getDefaultGraphicMode();
- public List AviableModes
+ public List AvailableModes
{
get
{
- return aviableModes;
+ return availableModes;
}
}
@@ -253,11 +253,11 @@ namespace Cosmos.System.Graphics
if (mode == null)
return false;
- foreach (var elem in aviableModes)
+ foreach (var elem in availableModes)
{
if (elem == mode)
{
- return true; // All OK mode does exists in aviableModes
+ return true; // All OK mode does exists in availableModes
}
}
@@ -273,21 +273,21 @@ namespace Cosmos.System.Graphics
}
#if false
/* This would have been the more "modern" version but LINQ is not working */
- if (!aviableModes.Exists(element => element == mode))
+ if (!availableModes.Exists(element => element == mode))
throw new ArgumentOutOfRangeException($"Mode {mode} is not supported by this Driver");
#endif
- foreach (var elem in aviableModes)
+ foreach (var elem in availableModes)
{
if (elem == mode)
{
Global.mDebugger.SendInternal($"mode {mode} found");
- return; // All OK mode does exists in aviableModes
+ return; // All OK mode does exists in availableModes
}
}
Global.mDebugger.SendInternal($"foreach ended mode is not found! Raising exception...");
/* 'mode' was not in the 'aviableModes' List ==> 'mode' in NOT Valid */
throw new ArgumentOutOfRangeException(nameof(mode), $"Mode {mode} is not supported by this Driver");
}
@@ -273,21 +273,21 @@ namespace Cosmos.System.Graphics
}
Global.mDebugger.SendInternal($"foreach ended mode is not found! Raising exception...");
- /* 'mode' was not in the 'aviableModes' List ==> 'mode' in NOT Valid */
+ /* 'mode' was not in the 'availableModes' List ==> 'mode' in NOT Valid */
throw new ArgumentOutOfRangeException(nameof(mode), $"Mode {mode} is not supported by this Driver");
}
diff --git a/source/Cosmos.System/Graphics/VBEScreen.cs b/source/Cosmos.System/Graphics/VBEScreen.cs
index 8ef8886dc..e216fe449 100644
--- a/source/Cosmos.System/Graphics/VBEScreen.cs
+++ b/source/Cosmos.System/Graphics/VBEScreen.cs
@@ -47,13 +47,13 @@ namespace Cosmos.System
}
}
-#region Display
+ #region Display
///
/// All the aviable screen modes VBE supports, I would like to query the hardware and obtain from it the list but I have
/// not yet find how to do it! For now I hardcode the most used VESA modes, VBE seems to support until HDTV resolution
/// without problems that is well... excellent :-)
///
- public override List getAviableModes()
+ public override List getAvailableModes()
{
return new List
{
@@ -92,9 +92,9 @@ namespace Cosmos.System
//set the screen
VBEDriver.VBESet(xres, yres, bpp);
}
-#endregion
+ #endregion
-#region Drawing
+ #region Drawing
public override void Clear(Color color)
{
@@ -160,12 +160,12 @@ namespace Cosmos.System
{
throw new NotImplementedException();
}
-#endregion
+ #endregion
-#region Reading
+ #region Reading
// TODO add to Canvas GetPointColor()
-#endregion
+ #endregion
}
}
@@ -47,13 +47,13 @@ namespace Cosmos.System
///
- /// All the aviable screen modes VBE supports, I would like to query the hardware and obtain from it the list but I have
+ /// All the available screen modes VBE supports, I would like to query the hardware and obtain from it the list but I have
/// not yet find how to do it! For now I hardcode the most used VESA modes, VBE seems to support until HDTV resolution
/// without problems that is well... excellent :-)